@@ -177,6 +177,6 @@ class SSHOperator(BaseOperator):
         return result
 
     def tunnel(self) -> None:
-        """Get ssh tunnel"""
+        """Get ssh tunnel."""
         ssh_client = self.ssh_hook.get_conn()  # type: ignore[union-attr]
         ssh_client.get_transport()
